#
# RevisionControlled interfaces
#
# Revision controlled files and directories
# File system only!
#
# Copyright (c) 2001-2003 by Philipp "philiKON" von Weitershausen
#
# This software is distributed under the terms of the Mozilla Public
# License (MPL)
#

"""
$Id: RevisionControlled.py,v 1.3 2003/05/02 13:58:06 philipp Exp $
"""

from Interface import Interface, Attribute

class IRCFile(Interface):
    """
    Revision controlled file
    """

    filename = Attribute("""
        Filename as string.
        """)

    relative_path = Attribute("""
        Relative file path as string.
        """)

    absolute_path = Attribute("""
        Absolute file path as string.
        """)

    isDirectory = Attribute("""
        Should always be false.
        """)
    
    def __init__(module_path, relative_path):
        """
        'module_path' is the absolute file path to the module.

        'relative_path' is the relative file path in the module.
        """

class IRCDirectory(Interface):
    """
    Directory containing revision controlled files
    """

    filename = Attribute("""
        Directory filename as string.
        """)

    relative_path = Attribute("""
        Relative directory path as string.
        """)

    absolute_path = Attribute("""
        Absolute directory path as string.
        """)

    isDirectory = Attribute(
        """Should always be true"""
        )

    def __init__(relative_path, module):
        """
        'relative_path' is the relative file path as string.

        'module' is an object implementing IModule.        
        """

    def getContents():
        """
        Return a sequence of objects representing the files and
        directories in this directory.
        """

    def getDirectoryListing(recursive=0):
        """
        Return a sorted sequence with directory contents.

        If 'recursive' is true, all files in all sub-directories are
        returned.
        """

    def hasFile(filename):
        """
        Return true if this directory contains a file with the file
        name 'filename'.
        """

    def traverse(path):
        """
        Return an object representing the file or directory identified
        by 'path'.
        
        'path' is relative to the result of getPath().
        """
