
"""
$Id: testShellCmdProc.py,v 1.6 2003/06/09 06:39:04 philipp Exp $
"""

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
from Products.RevisionManager.ShellCommandProcessor import ShellCommandProcessor
from Products.RevisionManager.interfaces.ShellCommandProcessor import IShellCommandProcessor

ZopeTestCase.installProduct('RevisionManager')

stubstring = "aGl678rjtl3jASGjsljfjh357lerg"

class ShellCmdProcPosixTest:
    """
    Test ShellCommandProcessor on Posix/UNIX
    """

    def test_verify_interface(self):
        """Verify interface implementation"""
        from Interface.Verify import verifyClass
        self.failUnless(verifyClass(IShellCommandProcessor, ShellCommandProcessor))

    def test_stdout(self):
        """Test stdout output"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams('echo -n "%s"' % stubstring)
        self.assertEqual(values[0], 0)
        self.assertEqual(values[1], stubstring)
        self.assertEqual(values[2], "")
    
    def test_stderr(self):
        """Test stderr output"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams('echo -n "%s" > /dev/stderr' % stubstring)
        self.assertEqual(values[0], 0)
        self.assertEqual(values[1], "")
        self.assertEqual(values[2], stubstring)

    def test_pipe(self):
        """Test pipe input"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams("cat", stubstring)
        self.assertEqual(values[0], 0)
        self.assertEqual(values[1], stubstring)
        self.assertEqual(values[2], "")
        
    def test_returnCode(self):
        """Test return code"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams("/bin/false")
        self.failUnless(values[0] != 0)
        values = shellproc.processStreams("/bin/true")
        self.assertEqual(values[0], 0)

class ShellCmdProcWin32Test:
    """
    Test ShellCommandProcessor on Win32
    """

    def test_verify_interface(self):
        """Verify interface implementation"""
        from Interface.Verify import verifyClass
        self.failUnless(verifyClass(IShellCommandProcessor, ShellCommandProcessor))

    def test_stdout(self):
        """Test stdout output"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams('echo %s' % stubstring)
        self.assertEqual(values[0], 0)
        self.assertEqual(values[1].strip(), stubstring)
        self.assertEqual(values[2], "")
    
    def test_stderr(self):
        """Test stderr output"""
        # not implemented on Win32

    def test_pipe(self):
        """Test pipe input"""
        shellproc = ShellCommandProcessor()
        values = shellproc.processStreams("sort", stubstring)
        self.assertEqual(values[0], 0)
        self.assertEqual(values[1].strip(), stubstring)
        self.assertEqual(values[2], "")
         
    def test_returnCode(self):
        """Test return code"""
        # not implemented on Win32

if sys.platform == "win32":
    class ShellCmdProcTest(ShellCmdProcWin32Test, ZopeTestCase.ZopeTestCase):
        pass
else:
    class ShellCmdProcTest(ShellCmdProcPosixTest, ZopeTestCase.ZopeTestCase):
        pass    

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(ShellCmdProcTest))
        return suite
